require 'spec_helper'
require 'dotenv'
require 'pry'
Dotenv.load

describe Lotohelp do

  before(:all) do
    @lottery_slug = "megasena"
    @concourse_number = 780
    @auth_token = ENV['AUTH_TOKEN']
    @auth_email = ENV['AUTH_EMAIL']
  end

  describe '#configuration' do
    it 'should return the configuration variable or nil' do
      token = "123123"

      Helpers::Helper.configure_api(token,nil)

      expect(Lotohelp::Config.auth_token).to eq token
      expect(Lotohelp::Config.auth_email).to eq nil
    end
  end

  describe '#request' do
    it 'should return 401 when auth information is empty or invalid' do
      token = nil
      email = "example@gmail.com"

      Helpers::Helper.configure_api(token, email)

      response = Lotohelp::Lottery.last(@lottery_slug)

      expect(response[:code]).to eq 401
    end
  end

  describe '#requests' do

    # Configuring API token
    # To set your credentials create an .env file and set the
    # AUTH_TOKEN and AUTH_EMAIL variables
    #
    before(:all) do
      Helpers::Helper.configure_api(@auth_token, @auth_email)
    end

    describe '#last_concourse' do
      it 'should validate params' do
        expect{ Lotohelp::Lottery.last() }.to raise_error
      end

      it 'should validate lottery slug' do
        response = Lotohelp::Lottery.last('megamega')

        expect(response[:body]["code"]).to eq 1
      end

      it 'should return last concourse' do
        response = Lotohelp::Lottery.last(@lottery_slug)

        expect(response[:code]).to eq 200
        expect(response[:body][0]["concourse"].class).to eq Hash
      end
    end

    describe '#get_concourse' do
      it 'should validate params' do
        expect{ Lotohelp::Concourse.get() }.to raise_error(ArgumentError)
      end

      it 'should return a specific concourse' do
        response = Lotohelp::Concourse.get(@concourse_number, @lottery_slug)

        expect(response[:code]).to eq 200
        expect(response[:body][0]["concourse"]["name"]).to eq @concourse_number
      end
    end

    describe '#check' do
      it 'should validate params' do
        expect{ Lotohelp::Concourse.check() }.to raise_error(ArgumentError)
      end

      it 'should check a game' do
        numbers = ["01","02","03", 10, 20]

        response = Lotohelp::Concourse.check(numbers, @concourse_number, @lottery_slug)

        expect(response[:code]).to eq 200
        expect(response[:body][0]["game"]["score"].class).to eq Fixnum
      end
    end

  end
end
